@@ -7,7 +7,7 @@ from extract_msg.attachment_base import AttachmentBase
 from extract_msg.named import NamedAttachmentProperties
 from extract_msg.prop import FixedLengthProp, VariableLengthProp
 from extract_msg.properties import Properties
-from extract_msg.utils import openMsg, verifyPropertyId, verifyType
+from extract_msg.utils import openMsg, inputToString, verifyPropertyId, verifyType
 
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
@@ -48,8 +48,8 @@ class Attachment(AttachmentBase):
         else:
             raise TypeError('Unknown attachment type.')
 
-    def save(self, contentId = False, json = False, useFileName = False, raw = False, customPath = None, customFilename = None,
-             html = False, rtf = False):
+    def save(self, contentId = False, json = False, useFileName = False, raw = False, customPath = None,
+             customFilename = None):#, html = False, rtf = False, allowFallback = False):
         # Check if the user has specified a custom filename
         filename = None
         if customFilename is not None and customFilename != '':
@@ -76,20 +76,23 @@ class Attachment(AttachmentBase):
                 customPath += '/'
             filename = customPath + filename
 
+        # Someone managed to have a null character here, so let's get rid of that
+        filename = inputToString(filename, self.msg.stringEncoding).replace('\x00', '')
+
         if self.__type == "data":
             with open(filename, 'wb') as f:
                 f.write(self.__data)
         else:
-            self.saveEmbededMessage(contentId, json, useFileName, raw, customPath, customFilename, html, rtf)
+            self.saveEmbededMessage(contentId, json, useFileName, raw, customPath, customFilename)#, html, rtf, allowFallback)
         return filename
 
     def saveEmbededMessage(self, contentId = False, json = False, useFileName = False, raw = False, customPath = None,
-                           customFilename = None, html = False, rtf = False):
+                           customFilename = None):#, html = False, rtf = False, allowFallback = False):
         """
         Seperate function from save to allow it to
         easily be overridden by a subclass.
         """
-        self.data.save(json, useFileName, raw, contentId, customPath, customFilename, html, rtf)
+        self.data.save(json, useFileName, raw, contentId, customPath, customFilename)#, html, rtf, allowFallback)
 
     @property
     def cid(self):
